@@ -280,6 +280,7 @@ class RuleDetailAPIView(RuleMixin, RetrieveUpdateDestroyAPIView):
                 "engaged": ""
             }
         """
+        #pylint:disable=useless-super-delegation
         return super(RuleDetailAPIView, self).put(request, *args, **kwargs)
 
     def delete(self, request, *args, **kwargs):
@@ -294,6 +295,7 @@ class RuleDetailAPIView(RuleMixin, RetrieveUpdateDestroyAPIView):
 
             DELETE /api/proxy/rules/app/ HTTP/1.1
         """
+        #pylint:disable=useless-super-delegation
         return super(RuleDetailAPIView, self).delete(request, *args, **kwargs)
 
 
@@ -337,7 +339,7 @@ class UserEngagementAPIView(ListAPIView):
             '-last_login').prefetch_related('engagements')
 
 
-class EngagementAPIView(GenericAPIView):
+class EngagementAPIView(AppMixin, GenericAPIView):
 
     serializer_class = EngagementsSerializer
     user_model = get_user_model()
@@ -352,7 +354,7 @@ class EngagementAPIView(GenericAPIView):
 
         .. code-block:: http
 
-            GET proxy/engagement/users/ HTTP/1.1
+            GET /api/proxy/engagement/ HTTP/1.1
 
         responds
 
@@ -360,6 +362,7 @@ class EngagementAPIView(GenericAPIView):
 
             {
                 "active_users": 10,
+                "authentication": "enabled",
                 "engagements": []
             }
         """
@@ -393,5 +396,6 @@ class EngagementAPIView(GenericAPIView):
             last_login__gt=yest_start, last_login__lt=yest_end).count()
 
         return Response(self.get_serializer({
+            'authentication': self.app.authentication,
             'engagements': engagement_stats,
             'active_users': users}).data)
